<?php
// 设置HTTP响应头，指定内容类型为XML
header("Content-type: text/xml");
// 发送HTTP响应头，指定状态码为200 OK
header('HTTP/1.1 200 OK');

// 包含WordPress配置文件和核心文件
include("wp-config.php");
require_once(ABSPATH.'./wp-blog-header.php');

// 获取最后一篇文章的修改时间（GMT时间）
$ltime = get_lastpostmodified("GMT");
// 将最后修改时间格式化为GMT时间格式
$ltime = gmdate('Y-m-d\TH:i:s+00:00', strtotime($ltime));

// 设置要显示的文章数量
$posts_to_show = 5000;

// 初始化XML字符串，设置XML头部和命名空间
$str = '<?xml version="1.0" encoding="UTF-8"?><urlset xmlns="https://www.sitemaps.org/schemas/sitemap/0.9" xmlns:mobile="http://www.baidu.com/schemas/sitemap-mobile/1/">';

// 添加首页的URL信息
$str .= "<url>\r\n";
$str .= "<loc>".get_home_url()."</loc>\r\n";
$str .= "<lastmod>".$ltime."</lastmod>\r\n";
$str .= "<changefreq>daily</changefreq>\r\n";
$str .= "<priority>1.0</priority>\r\n";
$str .= "</url>\r\n";

// 获取指定数量的文章，并为每篇文章添加URL信息
$myposts = get_posts("numberposts=".$posts_to_show);
foreach ($myposts as $post) {
    $post_modified = get_page($post->ID)->post_modified; // 一次性获取文章修改时间
    $str .= "<url>\r\n";
    $str .= "<loc>".urldecode(get_permalink())."</loc>\r\n";
    $str .= "<lastmod>".str_replace(" ","T", $post_modified)."</lastmod>\r\n"; // 使用获取的文章修改时间
    $str .= "<changefreq>monthly</changefreq>\r\n";
    $str .= "<priority>0.6</priority>\r\n";
    $str .= "</url>\r\n";
}

// 获取所有文章标签，并为每个标签添加URL信息
$tags = get_terms("post_tag");
foreach ($tags as $key => $tag) {
    $link = get_term_link(intval($tag->term_id), "post_tag");
    // 检查获取标签链接是否出错
    if (is_wp_error($link)) {
        // 输出错误信息或记录日志
        echo "获取标签链接时出错：" . $link->get_error_message();
        // 终止循环
        break;
    }
    $tags[$key]->link = $link;
    $post_modified = get_page($tag->ID)->post_modified; // 一次性获取标签修改时间
    $str .= "<url>\r\n";
    $str .= "<loc>".urldecode($link)."</loc>\r\n";
    $str .= "<lastmod>".str_replace(" ","T", $post_modified)."</lastmod>\r\n"; // 使用获取的标签修改时间
    $str .= "<changefreq>daily</changefreq>\r\n";
    $str .= "<priority>0.4</priority>\r\n";
    $str .= "</url>\r\n";
}

// 获取所有文章分类，并为每个分类添加URL信息
$terms = get_terms('category', 'orderby=name&hide_empty=0');
$count = count($terms);
if ($count > 0) {
    foreach ($terms as $term) {
        $post_modified = get_page($term->ID)->post_modified; // 一次性获取分类修改时间
        $str .= "<url>\r\n";
        $str .= "<loc>".urldecode(get_term_link($term, $term->slug))."</loc>\r\n";
        $str .= "<lastmod>".str_replace(" ","T", $post_modified)."</lastmod>\r\n"; // 使用获取的分类修改时间
        $str .= "<changefreq>weekly</changefreq>\r\n";
        $str .= "<priority>0.8</priority>\r\n";
        $str .= "</url>\r\n";
    }
}

// 获取所有页面，并为每个页面添加URL信息
$mypages = get_pages();
if (count($mypages) > 0) {
    foreach ($mypages as $page) {
        $post_modified = get_page($page->ID)->post_modified; // 一次性获取页面修改时间
        $str .= "<url>\r\n";
        $str .= "<loc>".urldecode(get_page_link($page->ID))."</loc>\r\n";
        $str .= "<lastmod>".str_replace(" ","T", $post_modified)."</lastmod>\r\n"; // 使用获取的页面修改时间
        $str .= "<changefreq>monthly</changefreq>\r\n";
        $str .= "<priority>0.6</priority>\r\n";
        $str .= "</url>\r\n";
    }
}

// 完成XML
$str .= "</urlset>";

// 将XML内容写入文件，并检查是否写入成功
if(file_put_contents('./sitemap.xml', $str) !== false) {
    // 如果写入成功，则输出成功消息，并提供 sitemap.xml 文件的链接
    echo '更新 sitemap.xml 成功！ <a href="/sitemap.xml"> 查看</a>';
} else {
    // 如果写入失败，则输出失败消息
    echo '更新 sitemap.xml 失败！';
}
?>
